@@ -1,4 +1,4 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 //! Error type.
 
@@ -39,6 +39,9 @@ pub enum SpringError {
     #[error("another thread sharing the same resource got panic")]
     ThreadPoisoned(anyhow::Error),
 
+    #[error("invalid config")]
+    InvalidConfig { source: anyhow::Error },
+
     #[error("invalid option (key `{key:?}`, value `{value:?}`)")]
     InvalidOption {
         key: String,
