@@ -1,9 +1,9 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 pub(crate) mod options_builder;
 
-pub(crate) mod in_memory_queue_server_options;
-pub(crate) mod net_server_options;
+pub(crate) mod in_memory_queue_options;
+pub(crate) mod net_options;
 
 use crate::error::{Result, SpringError};
 use anyhow::Context;
