@@ -1,19 +1,18 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
-pub(crate) mod pump_state;
-
-use serde::{Deserialize, Serialize};
+pub(crate) mod pump_input_type;
+pub(crate) mod window_operation_parameter;
+pub(crate) mod window_parameter;
 
 use crate::stream_engine::command::{insert_plan::InsertPlan, query_plan::QueryPlan};
 
-use self::pump_state::PumpState;
+use self::pump_input_type::PumpInputType;
 
 use super::name::{PumpName, StreamName};
 
-#[derive(Clone, Eq, PartialEq, Debug, Serialize, Deserialize, new)]
+#[derive(Clone, PartialEq, Debug, new)]
 pub(crate) struct PumpModel {
     name: PumpName,
-    state: PumpState,
     query_plan: QueryPlan,
     insert_plan: InsertPlan,
 }
@@ -23,8 +22,8 @@ impl PumpModel {
         &self.name
     }
 
-    pub(crate) fn state(&self) -> &PumpState {
-        &self.state
+    pub(crate) fn input_type(&self) -> PumpInputType {
+        self.query_plan.input_type()
     }
 
     pub(crate) fn query_plan(&self) -> &QueryPlan {
@@ -43,11 +42,4 @@ impl PumpModel {
     pub(crate) fn downstream(&self) -> &StreamName {
         self.insert_plan.stream()
     }
-
-    pub(crate) fn started(&self) -> Self {
-        Self {
-            state: PumpState::Started,
-            ..self.clone()
-        }
-    }
 }
